@@ -9,20 +9,20 @@ from django.utils.translation import ugettext_lazy as _
 DOCUMENTS_CACHE_KEYS_TO_CLEAN = getattr(settings, 'DOCUMENTS_CACHE_KEYS_TO_CLEAN', [])
 
 # Forbidden words for slug values in documents
-DOCUMENTS_PAGE_RESERVED_SLUGS = getattr(settings, 'DOCUMENTS_PAGE_MENU', ('board','add','preview','documents-help','inserts'))
+DOCUMENTS_PAGE_RESERVED_SLUGS = getattr(settings, 'DOCUMENTS_PAGE_MENU', ('add','board','help','inserts','preview','sitemap'))
 
 # Default template to generate tree menu
-DOCUMENTS_PAGE_TREEMENU = getattr(settings, 'DOCUMENTS_PAGE_TREEMENU', "sveedocuments/page_treemenu.html")
+DOCUMENTS_PAGE_TREEMENU = getattr(settings, 'DOCUMENTS_PAGE_TREEMENU', "sveedocuments/menu_tree.html")
 # Default template to generate flat menu
-DOCUMENTS_PAGE_FLATMENU = getattr(settings, 'DOCUMENTS_PAGE_FLATMENU', "sveedocuments/page_flatmenu.html")
+DOCUMENTS_PAGE_FLATMENU = getattr(settings, 'DOCUMENTS_PAGE_FLATMENU', "sveedocuments/menu_flat.html")
 
 # Enable or disable Pages archiving
 DOCUMENTS_PAGE_ARCHIVED = True
 
 # Available templates for Pages
 DOCUMENTS_PAGE_TEMPLATES = {
-    'default': ('sveedocuments/page_details/default.html', _('Default template with document content only')),
-    'with_toc': ('sveedocuments/page_details/with_toc.html', _('Template with a Table Of Content and the document content')),
+    'default': ('sveedocuments/page_details/page_default.html', _('Default template with document content only')),
+    'with_toc': ('sveedocuments/page_details/page_with-toc.html', _('Template with a Table Of Content and the document content')),
 }
 DOCUMENTS_PAGE_TEMPLATES.update(getattr(settings, 'DOCUMENTS_PAGE_TEMPLATES', {}))
 
@@ -42,30 +42,30 @@ CODEMIRROR_SETTINGS = {
     'sveetchies-documents-page': {
         'mode': 'rst',
         'csrf': 'CSRFpass',
-        'preview_url': ('documents-preview',),
-        #'quicksave_url': ('documents-page-quicksave',),
+        'preview_url': ('sveedocuments:preview',),
+        #'quicksave_url': ('sveedocuments:page-quicksave',),
         #'quicksave_datas': 'DJANGOCODEMIRROR_OBJECT',
         'quicksave_url': None,
         'lineWrapping': False,
         'lineNumbers': True,
         'search_enabled': True,
         #'settings_cookie': DJANGOCODEMIRROR_USER_SETTINGS_COOKIE_NAME,
-        'help_link': ('documents-help',),
-        'settings_url': ('documents-editor-settings', [], {}),
+        'help_link': ('sveedocuments:help',),
+        'settings_url': ('sveedocuments:editor-settings', [], {}),
     },
     'sveetchies-documents-insert': {
         'mode': 'rst',
         'csrf': 'CSRFpass',
-        'preview_url': ('documents-preview',),
-        #'quicksave_url': ('documents-insert-quicksave',),
+        'preview_url': ('sveedocuments:preview',),
+        #'quicksave_url': ('sveedocuments:insert-quicksave',),
         #'quicksave_datas': 'DJANGOCODEMIRROR_OBJECT',
         'quicksave_url': None,
         'lineWrapping': False,
         'lineNumbers': True,
         'search_enabled': True,
         #'settings_cookie': DJANGOCODEMIRROR_USER_SETTINGS_COOKIE_NAME,
-        'help_link': ('documents-help',),
-        'settings_url': ('documents-editor-settings', [], {}),
+        'help_link': ('sveedocuments:help',),
+        'settings_url': ('sveedocuments:editor-settings', [], {}),
     },
 }
 
